Package: svyweight
Title: Quick and Flexible Survey Weighting
Version: 0.1.1
Authors@R: 
    person(given = "Ben",
           family = "Mainwaring",
           role = c("aut", "cre"),
           email = "mainwaringb@gmail.com")
Description: Quickly and flexibly calculates weights for survey data, in order to correct
    for survey non-response or other sampling issues. Uses rake weighting, a common technique 
    also know as rim weighting or iterative proportional fitting.  This technique allows for weighting 
    on multiple variables, even when the interlocked distribution of the two
    variables is not known. Interacts with Thomas Lumley's 'survey' package, as described in 
    Lumley, Thomas (2011, ISBN:978-1-118-21093-2). Adds additional functionality, more adaptable syntax, and error-checking
    to the base weighting functionality in 'survey.'
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: survey, gdata, stats
Depends: R (>= 3.5.00)
Suggests: dplyr, srvyr, testthat, mice
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-29 19:48:02 UTC; apparatchiq
Author: Ben Mainwaring [aut, cre]
Maintainer: Ben Mainwaring <mainwaringb@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-29 20:40:02 UTC
Built: R 4.6.0; ; 2026-04-28 12:06:24 UTC; unix
