# Generated by roxygen2: do not edit by hand

S3method(as.w8margin,data.frame)
S3method(as.w8margin,matrix)
S3method(as.w8margin,numeric)
export(as.w8margin)
export(eff_n)
export(impute_w8margin)
export(rakesvy)
export(rakew8)
export(w8margin_matched)
export(weight_eff)
import(survey)
